@@ -182,11 +182,12 @@ except:
 import itertools
 
 import nflgame.game
+import nflgame.live
 import nflgame.player
 import nflgame.schedule
 import nflgame.seq
 
-VERSION = "1.1.1"
+VERSION = "1.1.2"
 
 NoPlayers = nflgame.seq.GenPlayerStats(None)
 """
@@ -272,7 +273,7 @@ def standard_team(team):
     return None
 
 
-def games(year, week=None, home=None, away=None, kind='REG'):
+def games(year, week=None, home=None, away=None, kind='REG', started=False):
     """
     games returns a list of all games matching the given criteria. Each
     game can then be queried for player statistics and information about
@@ -302,11 +303,18 @@ def games(year, week=None, home=None, away=None, kind='REG'):
     from the NFL web site. A game's JSON data is *only* cached to disk once
     the game is over, so be careful with the number of times you call this
     while a game is going on. (i.e., don't piss off NFL.com.)
+
+    If started is True, then only games that have already started (or are
+    about to start in less than 5 minutes) will be returned. Note that the
+    started parameter requires pytz to be installed. This is useful when
+    you only want to collect stats from games that have JSON data available
+    (as opposed to waiting for a 404 error from NFL.com).
     """
-    return list(games_gen(year, week, home, away, kind))
+    return list(games_gen(year, week, home, away, kind, started))
 
 
-def games_gen(year, week=None, home=None, away=None, kind='REG'):
+def games_gen(year, week=None, home=None, away=None,
+              kind='REG', started=False):
     """
     games returns a generator of all games matching the given criteria. Each
     game can then be queried for player statistics and information about
@@ -336,8 +344,14 @@ def games_gen(year, week=None, home=None, away=None, kind='REG'):
     from the NFL web site. A game's JSON data is *only* cached to disk once
     the game is over, so be careful with the number of times you call this
     while a game is going on. (i.e., don't piss off NFL.com.)
+
+    If started is True, then only games that have already started (or are
+    about to start in less than 5 minutes) will be returned. Note that the
+    started parameter requires pytz to be installed. This is useful when
+    you only want to collect stats from games that have JSON data available
+    (as opposed to waiting for a 404 error from NFL.com).
     """
-    infos = _search_schedule(year, week, home, away, kind)
+    infos = _search_schedule(year, week, home, away, kind, started)
     if not infos:
         return None
 
@@ -347,7 +361,7 @@ def games_gen(year, week=None, home=None, away=None, kind='REG'):
     return gen()
 
 
-def one(year, week, home, away, kind='REG'):
+def one(year, week, home, away, kind='REG', started=False):
     """
     one returns a single game matching the given criteria. The
     game can then be queried for player statistics and information about
@@ -377,8 +391,14 @@ def one(year, week, home, away, kind='REG'):
     from the NFL web site. A game's JSON data is *only* cached to disk once
     the game is over, so be careful with the number of times you call this
     while a game is going on. (i.e., don't piss off NFL.com.)
+
+    If started is True, then only games that have already started (or are
+    about to start in less than 5 minutes) will be returned. Note that the
+    started parameter requires pytz to be installed. This is useful when
+    you only want to collect stats from games that have JSON data available
+    (as opposed to waiting for a 404 error from NFL.com).
     """
-    infos = _search_schedule(year, week, home, away, kind)
+    infos = _search_schedule(year, week, home, away, kind, started)
     if not infos:
         return None
     assert len(infos) == 1, 'More than one game matches the given criteria.'
@@ -387,6 +407,9 @@ def one(year, week, home, away, kind='REG'):
 
 def combine(games, plays=False):
     """
+    DEPRECATED. Please use one of nflgame.combine_{game,play,max}_stats
+    instead.
+
     Combines a list of games into one big player sequence containing game
     level statistics.
 
@@ -399,11 +422,55 @@ def combine(games, plays=False):
     goal blocks, etc.
     """
     if plays:
-        return reduce(lambda ps1, ps2: ps1 + ps2,
-                      [g.drives.players() for g in games])
+        return combine_play_stats(games)
     else:
-        return reduce(lambda ps1, ps2: ps1 + ps2,
-                      [g.players for g in games])
+        return combine_game_stats(games)
+
+
+def combine_game_stats(games):
+    """
+    Combines a list of games into one big player sequence containing game
+    level statistics.
+
+    This can be used, for example, to get GamePlayerStats objects corresponding
+    to statistics across an entire week, some number of weeks or an entire
+    season.
+    """
+    return reduce(lambda ps1, ps2: ps1 + ps2, [g.players for g in games])
+
+
+def combine_play_stats(games):
+    """
+    Combines a list of games into one big player sequence containing play
+    level statistics.
+
+    This can be used, for example, to get PlayPlayerStats objects corresponding
+    to statistics across an entire week, some number of weeks or an entire
+    season.
+
+    This function should be used in lieu of combine_game_stats when more
+    detailed statistics such as receiver targets, yards after the catch and
+    punt/FG blocks are needed.
+
+    N.B. Since this combines *all* play data, this function may take a while
+    to complete depending on the number of games passed in.
+    """
+    return reduce(lambda p1, p2: p1 + p2, [g.drives.players() for g in games])
+
+
+def combine_max_stats(games):
+    """
+    Combines a list of games into one big player sequence containing maximum
+    statistics based on game and play level statistics.
+
+    This can be used, for example, to get GamePlayerStats objects corresponding
+    to statistics across an entire week, some number of weeks or an entire
+    season.
+
+    This function should be used in lieu of combine_game_stats or
+    combine_play_stats when the best possible accuracy is desired.
+    """
+    return reduce(lambda a, b: a + b, [g.max_player_stats() for g in games])
 
 
 def combine_plays(games):
@@ -415,7 +482,8 @@ def combine_plays(games):
     return nflgame.seq.GenPlays(chain)
 
 
-def _search_schedule(year, week=None, home=None, away=None, kind='REG'):
+def _search_schedule(year, week=None, home=None, away=None, kind='REG',
+                     started=False):
     """
     Searches the schedule to find the game identifiers matching the criteria
     given.
@@ -436,6 +504,12 @@ def _search_schedule(year, week=None, home=None, away=None, kind='REG'):
     year that a game was played in. For example, a Super Bowl taking place
     in the year 2011 actually belongs to the 2010 season. Also, the year
     parameter may be set to a list of seasons just like the week parameter.
+
+    If started is True, then only games that have already started (or are
+    about to start in less than 5 minutes) will be returned. Note that the
+    started parameter requires pytz to be installed. This is useful when
+    you only want to collect stats from games that have JSON data available
+    (as opposed to waiting for a 404 error from NFL.com).
     """
     infos = []
     for (y, t, w, h, a), info in nflgame.schedule.games:
@@ -459,5 +533,10 @@ def _search_schedule(year, week=None, home=None, away=None, kind='REG'):
                 continue
         if t != kind:
             continue
+        if started:
+            gametime = nflgame.live._game_datetime(info)
+            now = nflgame.live._now()
+            if gametime > now and (gametime - now).total_seconds() > 300:
+                continue
         infos.append(info)
     return infos
